pub struct ABIDecoder {}Implementations
Sourceimpl ABIDecoder
impl ABIDecoder
pub fn new() -> ABIDecoder
Sourcepub fn decode<'a>(
&mut self,
types: &[ParamType],
data: &'a [u8],
) -> Result<Vec<Token>, CodecError>
pub fn decode<'a>( &mut self, types: &[ParamType], data: &'a [u8], ) -> Result<Vec<Token>, CodecError>
Decode takes an array of ParamType and the encoded data as raw bytes
and returns a vector of Tokens containing the decoded values.
Note that the order of the types in the types array needs to match the order
of the expected values/types in data.
You can find comprehensive examples in the tests for this module.