pub struct ContractCall<D> {
pub fuel_client: FuelClient,
pub compiled_contract: CompiledContract,
pub encoded_args: Vec<u8>,
pub encoded_selector: Selector,
pub contract_id: ContractId,
pub gas_price: u64,
pub gas_limit: u64,
pub maturity: u64,
pub datatype: PhantomData<D>,
pub output_params: Vec<ParamType>,
pub custom_inputs: bool,
}Expand description
Helper for managing a transaction before submitting it to a node
Fields
fuel_client: FuelClientcompiled_contract: CompiledContractencoded_args: Vec<u8>encoded_selector: Selectorcontract_id: ContractIdgas_price: u64gas_limit: u64maturity: u64datatype: PhantomData<D>output_params: Vec<ParamType>custom_inputs: boolImplementations
Sourceimpl<D> ContractCall<D>where
D: Detokenize,
impl<D> ContractCall<D>where
D: Detokenize,
Sourcepub async fn call(self) -> Result<D, Error>
pub async fn call(self) -> Result<D, Error>
Call a contract’s method. Note that it will return
the method’s value as an actual typed value D.
For instance, if your method returns a bool, this will be a
Result<bool, Error>. Also works for structs! If your method
returns MyStruct, MyStruct will be generated through the abigen!()
and this will return Result<MyStruct, Error>.