pub enum Source {
String(String),
Local(PathBuf),
}Expand description
A source of a Truffle artifact JSON.
Variants
Implementations
Sourceimpl Source
impl Source
Sourcepub fn parse<S>(source: S) -> Result<Self, Error>
pub fn parse<S>(source: S) -> Result<Self, Error>
Parses an ABI from a source
Contract ABIs can be retrieved from the local filesystem or it can be provided in-line. It accepts:
-
raw ABI JSON
-
relative/path/to/Contract.json: a relative path to an ABI JSON file. This relative path is rooted in the current working directory. To specify the root for relative paths, useSource::with_root. -
/absolute/path/to/Contract.jsonorfile:///absolute/path/to/Contract.json: an absolute path or file URL to an ABI JSON file.